==> cs_models-0.0.389-py3-none-any.whl: cs_models/resources/CompanyScientificLink/schemas.py <==
from marshmallow import (
    Schema,
    fields,
    validate,
    pre_load,
    ValidationError,
)
from ...utils.utils import pre_load_date_fields


class CompanyScientificLinkResourceSchema(Schema):
    not_blank = validate.Length(min=1, error='Field cannot be blank')

    id = fields.Integer(dump_only=True)
    doi = fields.String(required=True, validate=not_blank)
    company_sec_id = fields.Integer(allow_none=True)
    company_ous_id = fields.Integer(allow_none=True)
    pubmed_id = fields.Integer(allow_none=True)
    date = fields.DateTime(allow_none=True)
    title = fields.String(allow_none=True)
    type = fields.String(allow_none=True)
    journal_title = fields.String(allow_none=True)
    inbound_ref_count = fields.Integer(allow_none=True)
    outbound_ref_count = fields.Integer(allow_none=True)
    orig_file_url = fields.String(allow_none=True)
    best_oa_location = fields.String(allow_none=True)
    method = fields.String(allow_none=True)
    verification = fields.String(allow_none=True)
    is_deleted = fields.Boolean(allow_none=True)
    updated_at = fields.DateTime(dump_only=True)

    @pre_load
    def pre_load(self, in_data, **kwargs):
        if self._get_number_of_company_fields(in_data) > 1:
            raise ValidationError('Provide either company_sec_id or '
                                  'company_ous_id, not both')

    def _get_number_of_company_fields(self, in_data, **kwargs):
        result = 0
        if 'company_sec_id' in in_data:
            if in_data['company_sec_id'] is not None:
                result += 1
        if 'company_ous_id' in in_data:
            if in_data['company_ous_id'] is not None:
                result += 1
        return result

    def convert_string_to_datetime(self, in_data, **kwargs):
        date_fields = ['date']

        in_data = pre_load_date_fields(
            in_data,
            date_fields,
            date_format='%Y%m%dT%H%M%S',
        )
        return in_data

==> cs_models-0.0.425-py3-none-any.whl: cs_models/resources/CompanyScientificLink/schemas.py <==
from marshmallow import (
    Schema,
    fields,
    validate,
    pre_load,
    ValidationError,
)
from ...utils.utils import pre_load_date_fields


class CompanyScientificLinkResourceSchema(Schema):
    not_blank = validate.Length(min=1, error='Field cannot be blank')

    id = fields.Integer(dump_only=True)
    doi = fields.String(required=True, validate=not_blank)
    company_sec_id = fields.Integer(allow_none=True)
    company_ous_id = fields.Integer(allow_none=True)
    pubmed_id = fields.Integer(allow_none=True)
    date = fields.DateTime(allow_none=True)
    title = fields.String(allow_none=True)
    type = fields.String(allow_none=True)
    journal_title = fields.String(allow_none=True)
    inbound_ref_count = fields.Integer(allow_none=True)
    outbound_ref_count = fields.Integer(allow_none=True)
    orig_file_url = fields.String(allow_none=True)
    best_oa_location = fields.String(allow_none=True)
    method = fields.String(allow_none=True)
    verification = fields.String(allow_none=True)
    is_deleted = fields.Boolean(allow_none=True)
    updated_at = fields.DateTime(dump_only=True)

    @pre_load
    def check_company_ids(self, in_data, **kwargs):
        if self._get_number_of_company_fields(in_data) > 1:
            raise ValidationError('Provide either company_sec_id or '
                                  'company_ous_id, not both')
        return in_data

    def _get_number_of_company_fields(self, in_data, **kwargs):
        result = 0
        if 'company_sec_id' in in_data:
            if in_data['company_sec_id'] is not None:
                result += 1
        if 'company_ous_id' in in_data:
            if in_data['company_ous_id'] is not None:
                result += 1
        return result

    @pre_load
    def convert_string_to_datetime(self, in_data, **kwargs):
        date_fields = ['date']

        in_data = pre_load_date_fields(
            in_data,
            date_fields,
            date_format='%Y%m%dT%H%M%S',
        )
        return in_data
